@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* Simple Double precision calculator using the GnomeCalculator widget
-   Copyright (C) 1998 Free Software Foundation
+   Copyright (C) 1998 Free Software Foundation, Inc.
 
    Author: George Lebl <jirka@5z.com>
 */
@@ -10,6 +10,7 @@
 #include <libgnomeui/gnome-window-icon.h>
 
 #include "gnome-calc.h"
+#include "sr.h"
 
 /* values for selection info */
 enum {
@@ -22,6 +23,16 @@ static GtkWidget *app;
 static GtkWidget *calc;
 static char copied_string[13]="";
 
+static gboolean
+may_run_slide_rule (GtkWidget *w, GdkEvent *event, gpointer data)
+{
+	if (event->type == GDK_3BUTTON_PRESS) {
+		run_slide_rule ();
+		return TRUE;
+	}
+	return FALSE;
+}
+
 static void
 about_cb (GtkWidget *widget, gpointer data)
 {
@@ -58,8 +69,8 @@ about_cb (GtkWidget *widget, gpointer data)
 	g_free (file);
 	
 	about = gnome_about_new(_("GNOME Calculator"), VERSION,
-				"(C) 1998 the Free Software Foundation",
-				_("Simple double precision calculator similiar "
+				_("(C) 1998 Free Software Foundation, Inc."),
+				_("Simple double precision calculator similar "
 				  "to xcalc"),
 				(const char **)authors,
 				(const char **)documenters,
@@ -70,6 +81,9 @@ about_cb (GtkWidget *widget, gpointer data)
 	}			
 
 	gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (data));
+	gtk_widget_add_events (about, GDK_BUTTON_PRESS_MASK);
+	gtk_signal_connect (GTK_OBJECT(about), "button_press_event", 
+			   GTK_SIGNAL_FUNC(may_run_slide_rule), NULL);
 	gtk_signal_connect(GTK_OBJECT(about), "destroy",
 			   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
@@ -188,7 +202,7 @@ main(int argc, char *argv[])
 			argc, argv, GNOME_PARAM_APP_DATADIR,DATADIR, NULL);
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-calc3.png");
 
-        app = gnome_app_new("gnome-calculator", _("GNOME Calculator"));
+        app = gnome_app_new("gnome-calculator", _("Calculator"));
 	gtk_window_set_wmclass (GTK_WINDOW (app), "gnome-calculator", "gnome-calculator");
 	gtk_window_set_resizable (GTK_WINDOW (app), TRUE);
 
@@ -199,7 +213,9 @@ main(int argc, char *argv[])
         gnome_app_create_menus_with_data(GNOME_APP(app), gcalc_menu, app);
 
 	calc = gnome_calc_new();
-	gnome_calc_bind_extra_keys (GNOME_CALC (calc), GTK_WIDGET (app));
+
+	gnome_calc_bind_extra_keys (GNOME_CALC (calc), GTK_WIDGET (app)); 
+
 	gtk_widget_show(calc);
 
 	gtk_selection_add_targets (GTK_WIDGET (app), GDK_SELECTION_CLIPBOARD,
@@ -215,8 +231,8 @@ main(int argc, char *argv[])
 				G_CALLBACK(client_die), NULL);
 
 	gnome_app_set_contents(GNOME_APP(app), calc);
-
 	/* add calculator accel table to our window*/
+
 	gtk_window_add_accel_group(GTK_WINDOW(app),
 				   gnome_calc_get_accel_group(GNOME_CALC(calc)));
 
