@@ -32,8 +32,6 @@
 #include <gnome.h>
 
 #include <regex.h>
-#include <gconf/gconf.h>
-#include <gconf/gconf-client.h>
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 #include <libgnomevfs/gnome-vfs-ops.h> 
 #include <bonobo-activation/bonobo-activation.h>
@@ -231,6 +229,14 @@ toggled (GtkToggleButton *tb)
 	disclosure = CDDB_DISCLOSURE (tb);
 	do_animation (disclosure, gtk_toggle_button_get_active (tb));
 
+	/*  Disabled for now.  By default we won't show the additional options section.
+	    But, keep the gconf key so advanced users can change the default behavior.
+	    
+	gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/show_additional_options",
+		       	       	       disclosure->priv->style == GTK_EXPANDER_COLLAPSED 
+				       ? TRUE : FALSE);
+	*/
+
 	if (disclosure->priv->container == NULL) {
 		return;
 	}
@@ -335,8 +341,6 @@ cddb_disclosure_set_container (CDDBDisclosure *disclosure,
 
 /* START OF THE GCONF FUNCTIONS */
 
-static GConfClient *global_gconf_client = NULL;
-
 gboolean
 gsearchtool_gconf_handle_error (GError **error)
 {
@@ -394,6 +398,43 @@ gsearchtool_gconf_get_string (const gchar *key)
 	return result;
 }
 
+gboolean 
+gsearchtool_gconf_get_boolean (const gchar *key)
+{
+	gboolean result;
+	GConfClient *client;
+	GError *error = NULL;
+	
+	g_return_val_if_fail (key != NULL, FALSE);
+	
+	client = gsearchtool_gconf_client_get_global ();
+	g_return_val_if_fail (client != NULL, FALSE);
+	
+	result = gconf_client_get_bool (client, key, &error);
+	
+	if (gsearchtool_gconf_handle_error (&error)) {
+		result = FALSE;
+	}
+	
+	return result;
+}
+
+void
+gsearchtool_gconf_set_boolean (const gchar *key, const gboolean flag)
+{
+	GConfClient *client;
+	GError *error = NULL;
+	
+	g_return_if_fail (key != NULL);
+	
+	client = gsearchtool_gconf_client_get_global ();
+	g_return_if_fail (client != NULL);
+	
+	gconf_client_set_bool (client, key, flag, &error);
+	
+	gsearchtool_gconf_handle_error (&error);
+}
+
 /* START OF GENERIC GNOME-SEARCH-TOOL FUNCTIONS */
 
 gboolean 
@@ -424,18 +465,18 @@ is_path_hidden (const gchar *path)
 	return results;
 }
 
-gboolean 
-is_path_in_mount_folder (const gchar *path)
-{
-	return (g_strstr_len (path, strlen ("/mnt/"), "/mnt/") != NULL);
-}
-
 gboolean 
 is_path_in_home_folder (const gchar *path)
 {
 	return (g_strstr_len (path, strlen (g_get_home_dir ()), g_get_home_dir ()) != NULL);
 }
 
+gboolean 
+is_path_in_mount_folder (const gchar *path)
+{
+	return (g_strstr_len (path, strlen ("/mnt/"), "/mnt/") != NULL);
+}
+
 gboolean
 file_extension_is (const char *filename, 
 		   const char *ext)
@@ -506,6 +547,27 @@ escape_single_quotes (const gchar *string)
 	return g_string_free (gs, FALSE);
 }
 
+gchar *
+remove_mnemonic_character (const gchar *string)
+{
+	GString *gs;
+	gboolean first_mnemonic = TRUE;
+	
+	if (string == NULL) {
+		return NULL;
+	}
+	
+	gs = g_string_new ("");
+	for(; *string; string++) {
+		if ((first_mnemonic == TRUE) && (*string == '_')) {
+			first_mnemonic = FALSE;
+			continue;
+		}
+		g_string_append_c(gs, *string);
+	}
+	return g_string_free (gs, FALSE);
+}
+
 gint
 count_of_char_in_string (const gchar *string, 
 			 const gchar q)
